aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorDan Gohman <gohman@apple.com>2008-07-27 18:06:42 +0000
committerDan Gohman <gohman@apple.com>2008-07-27 18:06:42 +0000
commit2a6299543fa22f389158409e897fe7099fda3812 (patch)
treebe8f316a54034b7b269bda5a924f8c03dddb3a42
parent7a24cdc4ed5c357e9de4e36a39379e0aa67f6f9c (diff)
downloadexternal_llvm-2a6299543fa22f389158409e897fe7099fda3812.zip
external_llvm-2a6299543fa22f389158409e897fe7099fda3812.tar.gz
external_llvm-2a6299543fa22f389158409e897fe7099fda3812.tar.bz2
Rename isOnlyUseOf to isOnlyUserOf.
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@54124 91177308-0d34-0410-b5e6-96231b3b80d8
-rw-r--r--include/llvm/CodeGen/SelectionDAGNodes.h4
-rw-r--r--lib/CodeGen/SelectionDAG/SelectionDAG.cpp4
2 files changed, 4 insertions, 4 deletions
diff --git a/include/llvm/CodeGen/SelectionDAGNodes.h b/include/llvm/CodeGen/SelectionDAGNodes.h
index 147b977..9690d8d 100644
--- a/include/llvm/CodeGen/SelectionDAGNodes.h
+++ b/include/llvm/CodeGen/SelectionDAGNodes.h
@@ -1199,9 +1199,9 @@ public:
/// value. This method ignores uses of other values defined by this operation.
bool hasAnyUseOfValue(unsigned Value) const;
/// isOnlyUseOf - Return true if this node is the only use of N.
///
- bool isOnlyUseOf(SDNode *N) const;
+ bool isOnlyUserOf(SDNode *N) const;
/// isOperandOf - Return true if this node is an operand of N.
///
@@ -1199,9 +1199,9 @@ public:
/// value. This method ignores uses of other values defined by this operation.
bool hasAnyUseOfValue(unsigned Value) const;
- /// isOnlyUseOf - Return true if this node is the only use of N.
+ /// isOnlyUserOf - Return true if this node is the only use of N.
///
diff --git a/lib/CodeGen/SelectionDAG/SelectionDAG.cpp b/lib/CodeGen/SelectionDAG/SelectionDAG.cpp
index 4fa5f58..366cb4c4 100644
--- a/lib/CodeGen/SelectionDAG/SelectionDAG.cpp
+++ b/lib/CodeGen/SelectionDAG/SelectionDAG.cpp
@@ -4581,9 +4581,9 @@ bool SDNode::hasAnyUseOfValue(unsigned Value) const {
}
/// isOnlyUseOf - Return true if this node is the only use of N.
///
-bool SDNode::isOnlyUseOf(SDNode *N) const {
+bool SDNode::isOnlyUserOf(SDNode *N) const {
bool Seen = false;
for (SDNode::use_iterator I = N->use_begin(), E = N->use_end(); I != E; ++I) {
SDNode *User = I->getUser();
@@ -4581,9 +4581,9 @@ bool SDNode::hasAnyUseOfValue(unsigned Value) const {
}
-/// isOnlyUseOf - Return true if this node is the only use of N.
+/// isOnlyUserOf - Return true if this node is the only use of N.
///